# Generated by Django 4.1.2 on 2022-11-25 23:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0012_alter_historicalpatientcall_last_attend_clinic_and_more"),
        ("intecomm_group", "0007_remove_historicalpatientfollowupcall_attend_date_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="patientgroup",
            name="dm_patients",
            field=models.ManyToManyField(
                blank=True,
                related_name="dm_patients",
                to="intecomm_screening.patientlog",
                verbose_name="DM-only",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="hiv_patients",
            field=models.ManyToManyField(
                blank=True,
                related_name="hiv_patients",
                to="intecomm_screening.patientlog",
                verbose_name="HIV-only",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="htn_patients",
            field=models.ManyToManyField(
                blank=True,
                related_name="htn_patients",
                to="intecomm_screening.patientlog",
                verbose_name="HTN-only",
            ),
        ),
        migrations.AddField(
            model_name="patientgroup",
            name="multi_patients",
            field=models.ManyToManyField(
                blank=True,
                related_name="multi_patients",
                to="intecomm_screening.patientlog",
                verbose_name="Multi-morbidity",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatientfollowupcall",
            name="last_attend_clinic",
            field=models.CharField(
                blank=True,
                help_text="This may be helpful when updating health records",
                max_length=25,
                null=True,
                verbose_name="Where did the patient last seek care",
            ),
        ),
        migrations.AlterField(
            model_name="patientfollowupcall",
            name="last_attend_clinic",
            field=models.CharField(
                blank=True,
                help_text="This may be helpful when updating health records",
                max_length=25,
                null=True,
                verbose_name="Where did the patient last seek care",
            ),
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-05 20:42

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0129_alter_bloodresultsfbc_options_and_more"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="bloodresultsfbc",
            name="intecomm_su_subject_1b56bc_idx",
        ),
        migrations.RemoveIndex(
            model_name="bloodresultsglu",
            name="intecomm_su_subject_da7231_idx",
        ),
        migrations.RemoveIndex(
            model_name="bloodresultshba1c",
            name="intecomm_su_subject_8d1ef7_idx",
        ),
        migrations.RemoveIndex(
            model_name="bloodresultsins",
            name="intecomm_su_subject_fa522d_idx",
        ),
        migrations.RemoveIndex(
            model_name="bloodresultslft",
            name="intecomm_su_subject_765b18_idx",
        ),
        migrations.RemoveIndex(
            model_name="bloodresultslipid",
            name="intecomm_su_subject_676609_idx",
        ),
        migrations.RemoveIndex(
            model_name="bloodresultsrft",
            name="intecomm_su_subject_e7a1d8_idx",
        ),
        migrations.RemoveIndex(
            model_name="clinicalnote",
            name="intecomm_su_subject_2180e7_idx",
        ),
        migrations.RemoveIndex(
            model_name="clinicalreview",
            name="intecomm_su_subject_e0c962_idx",
        ),
        migrations.RemoveIndex(
            model_name="clinicalreviewbaseline",
            name="intecomm_su_subject_669150_idx",
        ),
        migrations.RemoveIndex(
            model_name="complicationsbaseline",
            name="intecomm_su_subject_fddb9d_idx",
        ),
        migrations.RemoveIndex(
            model_name="complicationsfollowup",
            name="intecomm_su_subject_3a5d93_idx",
        ),
        migrations.RemoveIndex(
            model_name="concomitantmedication",
            name="intecomm_su_subject_d4d0fa_idx",
        ),
        migrations.RemoveIndex(
            model_name="dminitialreview",
            name="intecomm_su_subject_532279_idx",
        ),
        migrations.RemoveIndex(
            model_name="dmmedicationadherence",
            name="intecomm_su_subject_ab34b8_idx",
        ),
        migrations.RemoveIndex(
            model_name="dmreview",
            name="intecomm_su_subject_bfb20e_idx",
        ),
        migrations.RemoveIndex(
            model_name="drugrefilldm",
            name="intecomm_su_subject_2df562_idx",
        ),
        migrations.RemoveIndex(
            model_name="drugrefillhiv",
            name="intecomm_su_subject_978ed1_idx",
        ),
    ]



from django.db import models
from edc_action_item.models import ActionModelMixin
from edc_constants.constants import CLINICAL_WITHDRAWAL, DEAD, NOT_APPLICABLE, OTHER
from edc_ltfu.constants import LOST_TO_FOLLOWUP
from edc_model.models import BaseUuidModel
from edc_model.validators import date_not_future
from edc_offstudy.constants import (
    COMPLETED_FOLLOWUP,
    CONSENT_WITHDRAWAL,
    END_OF_STUDY_ACTION,
)
from edc_offstudy.model_mixins import OffstudyModelMixin
from edc_sites.model_mixins import SiteModelMixin
from edc_transfer.constants import TRANSFERRED

from intecomm_lists.models import OffstudyReasons

from ..choices import CLINICAL_WITHDRAWAL_REASONS


class EndOfStudy(SiteModelMixin, ActionModelMixin, OffstudyModelMixin, BaseUuidModel):
    action_name = END_OF_STUDY_ACTION

    tracking_identifier_prefix = "ST"

    last_seen_date = models.DateField(
        verbose_name="Date patient was last seen",
        validators=[date_not_future],
        blank=False,
        null=True,
    )

    offstudy_reason = models.ForeignKey(
        OffstudyReasons,
        verbose_name="Reason patient was terminated from the study",
        on_delete=models.PROTECT,
        null=True,
        limit_choices_to={
            "name__in": [
                COMPLETED_FOLLOWUP,
                CONSENT_WITHDRAWAL,
                CLINICAL_WITHDRAWAL,
                LOST_TO_FOLLOWUP,
                TRANSFERRED,
                DEAD,
                OTHER,
            ]
        },
    )

    other_offstudy_reason = models.TextField(
        verbose_name="If OTHER, please specify", max_length=500, blank=True, null=True
    )

    clinical_withdrawal_reason = models.CharField(
        verbose_name=(
            "If the patient was withdrawn on CLINICAL grounds, "
            "please specify PRIMARY reason"
        ),
        max_length=25,
        choices=CLINICAL_WITHDRAWAL_REASONS,
        default=NOT_APPLICABLE,
    )

    clinical_withdrawal_reason_other = models.TextField(
        verbose_name="If withdrawn for 'other' condition, please explain",
        max_length=500,
        blank=True,
        null=True,
    )

    clinical_withdrawal_investigator_decision = models.TextField(
        verbose_name="If withdrawl was an 'investigator decision', please explain ...",
        max_length=500,
        blank=True,
        null=True,
    )

    ltfu_date = models.DateField(
        verbose_name="Date lost to followup, if applicable",
        validators=[date_not_future],
        blank=True,
        null=True,
        help_text="A Loss to followup report must be on file",
    )

    transfer_date = models.DateField(
        verbose_name="Date of transfer, if applicable",
        validators=[date_not_future],
        blank=True,
        null=True,
        help_text="A Transfer form must be on file.",
    )

    death_date = models.DateField(
        verbose_name="Date of death, if applicable",
        validators=[date_not_future],
        blank=True,
        null=True,
        help_text="A Death report must be on file",
    )

    comment = models.TextField(
        verbose_name="Please provide further details if possible",
        max_length=500,
        blank=True,
        null=True,
    )

    class Meta(OffstudyModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "End of Study"
        verbose_name_plural = "End of Study"
        indexes = (
            ActionModelMixin.Meta.indexes
            + BaseUuidModel.Meta.indexes
            + [models.Index(fields=["subject_identifier", "action_identifier", "site", "id"])]
        )



from textwrap import fill

from edc_adverse_event.pdf_reports import AePdfReport as BaseAeReport
from reportlab.lib.units import cm
from reportlab.platypus import Table


class AePdfReport(BaseAeReport):
    weight_model = "intecomm_subject.followup"
    logo_data = {
        "app_label": "intecomm_edc",
        "filename": "meta_logo.png",
        "first_page": (4.0 * cm, 0.83 * cm),
        "later_pages": (3.0 * cm, 0.625 * cm),
    }

    def _draw_ae_overview(self, story):
        # basics
        classification_text = fill(self.ae_initial.ae_classification_as_text, width=80)
        rows = [
            ["Reference:", self.ae_initial.identifier],
            [
                "Report date:",
                self.ae_initial.report_datetime.strftime("%Y-%m-%d %H:%M"),
            ],
            ["Awareness date:", self.ae_initial.ae_awareness_date.strftime("%Y-%m-%d")],
            ["Actual start date:", self.ae_initial.ae_start_date.strftime("%Y-%m-%d")],
            ["Classification:", classification_text],
            ["Severity:", self.ae_initial.get_ae_grade_display()],
        ]

        t = Table(rows, (4 * cm, 14 * cm))
        self.set_table_style(t, bg_cmd=self.bg_cmd)
        t.hAlign = "LEFT"
        story.append(t)

    def _draw_ae_drug_relationship(self, story):
        pass

    def _draw_ae_cause(self, story):
        pass



from django import forms

from ..models import ArvRegimens, DrugSupplyHiv


class DrugSupplyHivForm(forms.ModelForm):
    list_model_cls = ArvRegimens
    relation_label = "drugsupplyhiv"

    def clean(self):
        cleaned_data = super().clean()
        if (
            self.cleaned_data.get("drug")
            and self.cleaned_data.get("drug").name
            not in self.cleaned_data.get("drug_refill").rx.name
        ):
            raise forms.ValidationError(
                f"Invalid. `{self.cleaned_data.get('drug').display_name}` "
                "not in current regimen "
                f"`{self.cleaned_data.get('drug_refill').rx.display_name}`"
            )
        return cleaned_data

    class Meta:
        model = DrugSupplyHiv
        fields = "__all__"



from django import forms
from edc_constants.constants import HIV
from edc_crf.crf_form_validator_mixins import CrfFormValidatorMixin
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_dx.form_validators import ResultFormValidatorMixin
from edc_form_validators.form_validator import FormValidator

from ..models import Cd4Result


class Cd4ResultFormValidator(ResultFormValidatorMixin, CrfFormValidatorMixin, FormValidator):
    dx = (HIV, "HIV infection")


class Cd4ResultForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = Cd4ResultFormValidator

    class Meta:
        model = Cd4Result
        fields = "__all__"



from django import forms
from intecomm_form_validators.subject import DrugRefillHtnFormValidator

from ..models import DrugRefillHtn
from .mixins import CrfModelFormMixin


class DrugRefillHtnForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = DrugRefillHtnFormValidator

    class Meta:
        model = DrugRefillHtn
        fields = "__all__"



from django.test import override_settings
from django.urls import reverse
from django_webtest import WebTest
from edc_dashboard import url_names
from edc_test_utils.get_user_for_tests import get_user_for_tests

from intecomm_dashboard.views import (
    AeListboardView,
    DeathReportListboardView,
    ScreenGroupListboardView,
    SubjectListboardView,
)
from intecomm_subject.models import DrugSupplyDm, DrugSupplyHiv, DrugSupplyHtn
from intecomm_subject.models import HealthEconomics as OldHealthEconomics


class TestViews(WebTest):
    def setUp(self) -> None:
        super().setUp()
        self.user = get_user_for_tests()
        self.user.is_superuser = True
        self.user.save()
        self.user.refresh_from_db()
        self.exclude_models = [
            DrugSupplyDm,
            DrugSupplyHtn,
            DrugSupplyHiv,
            OldHealthEconomics,
        ]

    def login(self):
        response = self.app.get(reverse("admin:index")).maybe_follow()
        for index, form in response.forms.items():
            if form.action == "/i18n/setlang/":
                # exclude the locale form
                continue
            else:
                break
        form["username"] = self.user.username
        form["password"] = "pass"  # nosec B105
        return form.submit()

    @override_settings(SITE_ID=101)
    def test_listboards_ok(self):
        self.login()

        url_name = url_names.get(ScreenGroupListboardView.listboard_url)
        url = reverse(url_name)
        response = self.app.get(url, user=self.user, status=200)
        self.assertIn(ScreenGroupListboardView.listboard_panel_title, response.text)

        url_name = url_names.get(AeListboardView.listboard_url)
        url = reverse(url_name)
        response = self.app.get(url, user=self.user, status=200)
        self.assertIn(AeListboardView.listboard_panel_title, response.text)

        url_name = url_names.get(SubjectListboardView.listboard_url)
        url = reverse(url_name)
        response = self.app.get(url, user=self.user, status=200)
        self.assertIn(SubjectListboardView.listboard_panel_title, response.text)

        url_name = url_names.get(DeathReportListboardView.listboard_url)
        url = reverse(url_name)
        response = self.app.get(url, user=self.user, status=200)
        self.assertIn(DeathReportListboardView.listboard_panel_title, response.text)



from edc_dx_review.model_mixins.factory import baseline_review_model_mixin_factory
from edc_model.models import BaseUuidModel
from edc_rx.model_mixins import TreatmentPayMethodsModelMixin
from edc_visit_schedule.constants import DAY1

from ..model_mixins import CrfModelMixin


class ClinicalReviewBaselineError(Exception):
    pass


class ClinicalReviewBaseline(
    TreatmentPayMethodsModelMixin,
    baseline_review_model_mixin_factory(),
    CrfModelMixin,
    BaseUuidModel,
):
    def save(self, *args, **kwargs):
        if (
            self.subject_visit.visit_code != DAY1
            and self.subject_visit.visit_code_sequence != 0
        ):
            raise ClinicalReviewBaselineError(
                f"This form is only available at baseline. Got `{self.subject_visit}`. "
                "Perhaps catch this in the form."
            )
        super().save(*args, **kwargs)

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Clinical Review: Baseline"
        verbose_name_plural = "Clinical Review: Baseline"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



# Generated by Django 4.1.7 on 2023-05-09 22:12

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0027_historicalpatientlog_printed_patientlog_printed"),
    ]

    operations = [
        migrations.AlterField(
            model_name="patientlogreportprinthistory",
            name="patient_log_identifier",
            field=models.CharField(max_length=36),
        ),
    ]



# Generated by Django 4.1.2 on 2022-11-22 19:59

from django.db import migrations, models
import edc_model.models.fields.other_charfield


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_group",
            "0006_remove_historicalpatientgroup_enforce_group_size_min_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalpatientfollowupcall",
            name="attend_date",
        ),
        migrations.RemoveField(
            model_name="patientfollowupcall",
            name="attend_date",
        ),
        migrations.AddField(
            model_name="historicalpatientfollowupcall",
            name="last_appt_date",
            field=models.DateField(
                blank=True,
                help_text="This may be helpful when updating health records",
                null=True,
                verbose_name="When did the patient last seek care",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientfollowupcall",
            name="last_attend_clinic",
            field=models.CharField(
                blank=True,
                choices=[],
                help_text="This may be helpful when updating health records",
                max_length=25,
                null=True,
                verbose_name="Where did the patient last seek care",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientfollowupcall",
            name="last_attend_clinic_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientfollowupcall",
            name="next_appt_date",
            field=models.DateField(
                blank=True, null=True, verbose_name="When will the patient next attend"
            ),
        ),
        migrations.AddField(
            model_name="patientfollowupcall",
            name="last_appt_date",
            field=models.DateField(
                blank=True,
                help_text="This may be helpful when updating health records",
                null=True,
                verbose_name="When did the patient last seek care",
            ),
        ),
        migrations.AddField(
            model_name="patientfollowupcall",
            name="last_attend_clinic",
            field=models.CharField(
                blank=True,
                choices=[],
                help_text="This may be helpful when updating health records",
                max_length=25,
                null=True,
                verbose_name="Where did the patient last seek care",
            ),
        ),
        migrations.AddField(
            model_name="patientfollowupcall",
            name="last_attend_clinic_other",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="patientfollowupcall",
            name="next_appt_date",
            field=models.DateField(
                blank=True, null=True, verbose_name="When will the patient next attend"
            ),
        ),
    ]



# Generated by Django 4.2.5 on 2023-09-19 21:58
from django.core.exceptions import ObjectDoesNotExist
from django.db import migrations
from django.db.migrations import RunPython
from django.db.models import ProtectedError
from edc_appointment.constants import MISSED_APPT, SKIPPED_APPT
from edc_appointment.utils import reset_appointment
from edc_metadata.models import CrfMetadata
from tqdm import tqdm


def delete_subject_visit_missed(apps, schema_editor):
    model_cls = apps.get_model("intecomm_subject.subjectvisitmissed")
    appointment_model_cls = apps.get_model("edc_appointment.appointment")
    subject_visit_model_cls = apps.get_model("intecomm_subject.subjectvisit")

    qs = model_cls.objects.filter(missed_reasons_other="NOT_SCHEDULED_FOR_FACILITY")
    total = qs.count()
    for subject_visit_missed in tqdm(qs, total=total):
        subject_visit_id = subject_visit_missed.subject_visit_id
        subject_visit = subject_visit_model_cls.objects.get(id=subject_visit_id)
        crf_metadata = CrfMetadata.objects.filter(
            model=subject_visit_missed._meta.label_lower,
            visit_schedule_name=subject_visit.visit_schedule_name,
            schedule_name=subject_visit.schedule_name,
            visit_code=subject_visit.visit_code,
            visit_code_sequence=0,
            subject_identifier=subject_visit.subject_identifier,
        )
        subject_visit_missed.delete()
        crf_metadata.delete()
        try:
            subject_visit = subject_visit_model_cls.objects.get(id=subject_visit_id)
        except ObjectDoesNotExist:
            pass
        else:
            appointment_id = subject_visit.appointment_id
            subject_visit.delete()
            appointment = appointment_model_cls.objects.get(id=appointment_id)
            appointment.related_visit = None
            reset_appointment(appointment)

    appointments = appointment_model_cls.objects.filter(
        appt_type_id__isnull=True,
        appt_timing__in=[MISSED_APPT, SKIPPED_APPT],
        visit_code_sequence=0,
    ).order_by("subject_identifier")
    total = appointments.count()
    for appointment in tqdm(appointments, total=total):
        try:
            obj = subject_visit_model_cls.objects.get(appointment_id=appointment.id)
        except ObjectDoesNotExist:
            appointment.related_visit = None
            reset_appointment(appointment)
        else:
            try:
                obj.delete()
            except ProtectedError as e:
                print(e)
            else:
                appointment.related_visit = None
                reset_appointment(appointment)


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0115_remove_historicalnextappointment_best_visit_code_and_more"),
    ]

    operations = [RunPython(delete_subject_visit_missed)]



from .ae_followup import AeFollowup
from .ae_initial import AeInitial
from .compatability import AeSusar, AeTmg, DeathReportTmg
from .death_report import DeathReport
from .hospitalization import Hospitalization



# Generated by Django 4.1.7 on 2023-05-10 00:43

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_screening",
            "0028_alter_patientlogreportprinthistory_patient_log_identifier",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalpatientlog",
            name="filing_identifier",
            field=models.CharField(
                blank=True,
                db_index=True,
                help_text="Auto-populated when form is saved. <BR>This is a sequential-like identifier to label this patient's paper file",
                max_length=36,
                verbose_name="Filing number",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatientlog",
            name="patient_log_identifier",
            field=models.CharField(
                blank=True,
                db_index=True,
                help_text="Auto-populated when form is saved. <BR>You may prefer to use the FILING NUMBER. <BR>This identifier is replaced by the 'screening identifier' if the patient screens for the INTECOMM trial",
                max_length=36,
                verbose_name="Patient Log Reference",
            ),
        ),
        migrations.AlterField(
            model_name="patientlog",
            name="filing_identifier",
            field=models.CharField(
                blank=True,
                help_text="Auto-populated when form is saved. <BR>This is a sequential-like identifier to label this patient's paper file",
                max_length=36,
                unique=True,
                verbose_name="Filing number",
            ),
        ),
        migrations.AlterField(
            model_name="patientlog",
            name="patient_log_identifier",
            field=models.CharField(
                blank=True,
                help_text="Auto-populated when form is saved. <BR>You may prefer to use the FILING NUMBER. <BR>This identifier is replaced by the 'screening identifier' if the patient screens for the INTECOMM trial",
                max_length=36,
                unique=True,
                verbose_name="Patient Log Reference",
            ),
        ),
    ]



# Generated by Django 4.1.2 on 2022-11-21 22:34

from django.db import migrations
import django_crypto_fields.fields.encrypted_char_field
import edc_model.validators.phone


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0004_rename_name_historicalpatientlog_legal_name_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalpatientcall",
            name="alt_contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[edc_model.validators.phone.phone_number],
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientcall",
            name="contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                validators=[edc_model.validators.phone.phone_number],
            ),
        ),
        migrations.AddField(
            model_name="patientcall",
            name="alt_contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[edc_model.validators.phone.phone_number],
            ),
        ),
        migrations.AddField(
            model_name="patientcall",
            name="contact_number",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text=" (Encryption: RSA local)",
                max_length=71,
                validators=[edc_model.validators.phone.phone_number],
            ),
        ),
    ]



# Generated by Django 4.2.3 on 2023-07-25 17:34

import uuid

import _socket
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_crypto_fields.fields.encrypted_text_field
import django_revision.revision_field
import edc_crf.model_mixins.crf_status_model_mixin
import edc_model.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_next_appointment", "0001_initial"),
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("intecomm_subject", "0059_historicalnextappointment_info_source_old_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalnextappointment",
            name="info_source",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                max_length=15,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_next_appointment.infosources",
                verbose_name="What is the source of this appointment date",
            ),
        ),
        migrations.AddField(
            model_name="nextappointment",
            name="info_source",
            field=models.ForeignKey(
                max_length=15,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_next_appointment.infosources",
                verbose_name="What is the source of this appointment date",
            ),
        ),
    ]



from django.db import models
from edc_model.models import BaseUuidModel
from edc_rx.model_mixins import DrugRefillModelMixin

from intecomm_lists.models import HtnTreatments

from ..model_mixins import CrfModelMixin


class DrugRefillHtn(DrugRefillModelMixin, CrfModelMixin, BaseUuidModel):
    rx = models.ManyToManyField(
        HtnTreatments,
        verbose_name="Which medicine did the patient receive today?",
    )

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Drug Refill: Hypertension"
        verbose_name_plural = "Drug Refills: Hypertension"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



# Generated by Django 4.2.1 on 2023-07-02 12:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0039_alter_historicalpatientlog_options_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="patient_log_identifier",
            field=models.CharField(
                max_length=50, null=True, verbose_name="Patient log identifier"
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="patient_log_identifier",
            field=models.CharField(
                max_length=50, null=True, verbose_name="Patient log identifier"
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="patient_log",
            field=models.OneToOneField(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="intecomm_screening.patientlog",
            ),
        ),
    ]



from django.utils.translation import gettext_lazy as _
from edc_crf.model_mixins import SingletonCrfModelMixin
from edc_he.model_mixins import IncomeModelMixin
from edc_model.models import BaseUuidModel

from ...model_mixins import CrfModelMixin


class HealthEconomicsIncome(
    SingletonCrfModelMixin,
    IncomeModelMixin,
    CrfModelMixin,
    BaseUuidModel,
):
    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = _("Health Economics: Income")
        verbose_name_plural = _("Health Economics: Income")
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from __future__ import annotations

from dataclasses import dataclass, field

from edc_sites.single_site import SingleSite


@dataclass(init=True)
class IntecommSite(SingleSite):
    health_facility_type: str = field(kw_only=True, default="")
    clinic_days: list[int] = field(kw_only=True, default_factory=list)

    def __str__(self):
        return f"{self.description} {self.health_facility_type.upper()} ({self.site_id})"



# Generated by Django 4.2.5 on 2023-10-05 23:19

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("edc_appointment", "0046_infosources"),
        ("intecomm_subject", "0117_historicalnextappointment_allow_create_interim_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalnextappointment",
            name="info_source_new",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                max_length=15,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_appointment.infosources",
                verbose_name="What is the source of this appointment date",
            ),
        ),
        migrations.AddField(
            model_name="nextappointment",
            name="info_source_new",
            field=models.ForeignKey(
                max_length=15,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_appointment.infosources",
                verbose_name="What is the source of this appointment date",
            ),
        ),
    ]



from __future__ import annotations

from typing import Any, Type

from django.urls import reverse
from django.utils.translation import gettext_lazy as _
from edc_sites.site import sites
from edc_subject_dashboard.views import SubjectDashboardView as BaseSubjectDashboardView
from intecomm_rando.constants import UGANDA

from intecomm_group.models import PatientGroup
from intecomm_group.utils import get_group_subject_dashboards_url
from intecomm_screening.models import PatientLog, PatientLogUg


class SubjectDashboardView(BaseSubjectDashboardView):
    navbar_selected_item = "subjects"
    visit_model = "intecomm_subject.subjectvisit"
    history_button_label = _("Audit")

    def __init__(self, **kwargs):
        self._patient_group = None
        super().__init__(**kwargs)

    def get(self, request, *args, **kwargs):
        return super().get(request, *args, **kwargs)

    def get_context_data(self, **kwargs) -> dict[str, Any]:
        if not self.patient_group:
            group_identifier = None
            group_name = None
            patient_group_url = None
        else:
            group_identifier = self.patient_group.group_identifier
            group_name = self.patient_group.name
            patient_group_url = reverse(
                "intecomm_group_admin:intecomm_group_patientgroup_changelist"
            )
            patient_group_url = f"{patient_group_url}?q={self.patient_group.name}"
        kwargs.update(
            subject_listboard_url="screen_group_url",
            group_identifier=group_identifier,
            group_name=group_name,
            patient_group_url=patient_group_url,
            patient_log=self.patient_log,
            patient_log_url=self.patient_log_url,
            group_subject_dashboards_url=get_group_subject_dashboards_url(self.patient_log),
        )
        return super().get_context_data(**kwargs)

    @property
    def patient_log_model_cls(self) -> Type[PatientLog | PatientLogUg]:
        if sites.get_current_country(self.request) == UGANDA:
            return PatientLogUg
        return PatientLog

    @property
    def patient_group(self) -> PatientGroup | None:
        if not self._patient_group:
            if self.patient_log.group_identifier:
                self._patient_group = PatientGroup.objects.get(
                    group_identifier=self.patient_log.group_identifier
                )
        return self._patient_group

    @property
    def patient_log(self):
        if self.subject_identifier:
            return self.patient_log_model_cls.objects.get(
                subject_identifier=self.subject_identifier
            )
        return None

    @property
    def patient_log_url(self) -> str:
        if self.patient_log:
            if self.patient_log.site.siteprofile.country == UGANDA:
                patient_log_url = reverse(
                    "intecomm_screening_admin:intecomm_screening_patientlogug_changelist"
                )
            else:
                patient_log_url = reverse(
                    "intecomm_screening_admin:intecomm_screening_patientlog_changelist"
                )
            url = f"{patient_log_url}?q={self.filing_identifier}"
        else:
            url = None
        return url

    @property
    def filing_identifier(self) -> str | None:
        if self.patient_log:
            return self.patient_log.filing_identifier
        return None



from django.core.validators import MaxValueValidator, MinValueValidator
from django.db import models
from edc_lab.choices import VL_QUANTIFIER_NA
from edc_lab.constants import EQ
from edc_lab.model_mixins import CrfWithRequisitionModelMixin, requisition_fk_options
from edc_lab_panel.panels import vl_panel
from edc_model.models import BaseUuidModel
from edc_reportable import COPIES_PER_MILLILITER

from ..model_mixins import CrfModelMixin


class ViralLoadResult(CrfWithRequisitionModelMixin, CrfModelMixin, BaseUuidModel):
    lab_panel = vl_panel

    requisition = models.ForeignKey(
        limit_choices_to={"panel__name": vl_panel.name}, **requisition_fk_options
    )

    vl_value = models.IntegerField(
        verbose_name="VL Result",
        validators=[MinValueValidator(20), MaxValueValidator(9999999)],
        help_text=f"in {COPIES_PER_MILLILITER}",
    )

    vl_quantifier = models.CharField(
        verbose_name="Quantifier", max_length=10, choices=VL_QUANTIFIER_NA, default=EQ
    )

    vl_units = models.CharField(
        verbose_name="Units", max_length=25, default=COPIES_PER_MILLILITER, editable=False
    )

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Viral Load Result"
        verbose_name_plural = "Viral Load Results"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from django.db import models
from django_crypto_fields.fields import EncryptedTextField
from edc_adverse_event.model_mixins import DeathReportModelMixin
from edc_constants.choices import YES_NO
from edc_model.models import BaseUuidModel
from edc_model_fields.fields import OtherCharField

from ..choices import DEATH_LOCATIONS, INFORMANT_RELATIONSHIP
from ..pdf_reports import DeathPdfReport


class DeathReport(DeathReportModelMixin, BaseUuidModel):
    pdf_report_cls = DeathPdfReport

    study_day = models.IntegerField(default=0, editable=False, help_text="not used")

    cause_of_death = models.TextField(
        verbose_name="Main cause of death",
        help_text=(
            "Main cause of death in the opinion of the local study doctor and local PI"
        ),
        null=True,
        blank=False,
    )

    death_location = models.CharField(
        verbose_name="Where did the participant die?",
        max_length=50,
        choices=DEATH_LOCATIONS,
    )

    hospital_name = models.CharField(
        verbose_name=(
            "If death occurred at hospital / clinic, please give name of the facility"
        ),
        max_length=150,
        null=True,
        blank=True,
    )

    informant_contact = EncryptedTextField(null=True, blank=True)

    informant_relationship = models.CharField(
        max_length=50,
        choices=INFORMANT_RELATIONSHIP,
        verbose_name="Informants relationship to the participant?",
    )

    other_informant_relationship = OtherCharField()

    death_certificate = models.CharField(
        verbose_name="Is a death certificate is available?",
        max_length=15,
        choices=YES_NO,
    )

    class Meta(DeathReportModelMixin.Meta, BaseUuidModel.Meta):
        indexes = DeathReportModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from edc_form_runners.decorators import register
from edc_form_runners.form_runner import FormRunner


@register()
class HtnMedicationAdherenceFormRunner(FormRunner):
    model_name = "intecomm_subject.htnmedicationadherence"
    exclude_formfields = ["pill_count"]


@register()
class DmMedicationAdherenceFormRunner(FormRunner):
    model_name = "intecomm_subject.dmmedicationadherence"
    exclude_formfields = ["pill_count"]


@register()
class HivMedicationAdherenceFormRunner(FormRunner):
    model_name = "intecomm_subject.hivmedicationadherence"
    exclude_formfields = ["pill_count"]


@register()
class SubjectVisitFormRunner(FormRunner):
    model_name = "intecomm_subject.subjectvisit"
    exclude_formfields = ["study_status"]


@register()
class SubjectRequisitionFormRunner(FormRunner):
    model_name = "intecomm_subject.subjectrequisition"
    exclude_formfields = ["clinic_verified", "clinic_verified_datetime"]


@register()
class HealthEconomicsAssetsFormRunner(FormRunner):
    model_name = "intecomm_subject.healtheconomicsassets"
    exclude_formfields = ["window_screen_type"]



from django.db import models
from edc_constants.choices import YES_NO
from edc_crf.model_mixins import SingletonCrfModelMixin
from edc_dx_review.model_mixins.factory import (
    dx_initial_review_model_mixin_factory,
    rx_initial_review_model_mixin_factory,
)
from edc_glucose.model_mixins import fasting_model_mixin_factory
from edc_glucose.model_mixins.glucose_model_mixin import glucose_model_mixin_factory
from edc_model.models import BaseUuidModel
from edc_model_fields.fields import OtherCharField

from intecomm_lists.models import DmManagement

from ..model_mixins import CrfModelMixin


class DmInitialReview(
    dx_initial_review_model_mixin_factory("dx"),
    rx_initial_review_model_mixin_factory(
        "rx_init", verbose_name_label="medicines for diabetes"
    ),
    glucose_model_mixin_factory("glucose"),
    fasting_model_mixin_factory(
        "glucose",
        verbose_names=dict(
            glucose_fasting="Was glucose measured while fasting?",
            glucose_fasting_duration_str="How long did they fast (in hours and minutes)?",
        ),
    ),
    SingletonCrfModelMixin,
    CrfModelMixin,
    BaseUuidModel,
):
    diagnosis_label = "diabetes"

    managed_by = models.ManyToManyField(
        DmManagement,
        verbose_name="How is the patient's diabetes managed?",
    )

    managed_by_other = OtherCharField()

    glucose_performed = models.CharField(
        verbose_name="Has the patient had their glucose measured in the last few months?",
        max_length=15,
        choices=YES_NO,
    )

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Diabetes Initial Review"
        verbose_name_plural = "Diabetes Initial Reviews"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from .arv_regimens import ArvRegimens
from .blood_results import (
    BloodResultsFbc,
    BloodResultsGlu,
    BloodResultsHba1c,
    BloodResultsIns,
    BloodResultsLft,
    BloodResultsLipid,
    BloodResultsRft,
)
from .cd4_result import Cd4Result
from .clinical_note import ClinicalNote
from .clinical_review import ClinicalReview
from .clinical_review_baseline import ClinicalReviewBaseline
from .complications_baseline import ComplicationsBaseline
from .complications_followup import ComplicationsFollowup
from .concomitant_medication import ConcomitantMedication
from .dm_initial_review import DmInitialReview
from .dm_medication_adherence import DmMedicationAdherence
from .dm_review import DmReview
from .drug_refill_dm import DrugRefillDm
from .drug_refill_hiv import DrugRefillHiv
from .drug_refill_htn import DrugRefillHtn
from .drug_supply_dm import DrugSupplyDm
from .drug_supply_hiv import DrugSupplyHiv
from .drug_supply_htn import DrugSupplyHtn
from .eq5d3l import Eq5d3l
from .family_history import FamilyHistory
from .glucose import Glucose
from .health_economics import (
    HealthEconomicsAssets,
    HealthEconomicsHouseholdHead,
    HealthEconomicsIncome,
    HealthEconomicsPatient,
    HealthEconomicsProperty,
)
from .health_economics_old import HealthEconomics
from .hiv_initial_review import HivInitialReview
from .hiv_medication_adherence import HivMedicationAdherence
from .hiv_review import HivReview
from .htn_initial_review import HtnInitialReview
from .htn_medication_adherence import HtnMedicationAdherence
from .htn_review import HtnReview
from .icecapa import Icecapa
from .location_update import LocationUpdate
from .malaria_test import MalariaTest
from .medications import Medications
from .next_appointment import NextAppointment
from .other_baseline_data import OtherBaselineData
from .social_harms import SocialHarms
from .subject_requisition import SubjectRequisition
from .subject_visit import SubjectVisit
from .subject_visit_missed import SubjectVisitMissed
from .urine_dipstick_test import UrineDipstickTest
from .urine_pregnancy import UrinePregnancy
from .viral_load_result import ViralLoadResult
from .vitals import Vitals



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple
from edc_dx_review.fieldsets import get_clinical_review_baseline_cond_fieldsets
from edc_dx_review.radio_fields import get_clinical_review_baseline_cond_radio_fields

from ..admin_site import intecomm_subject_admin
from ..forms import ClinicalReviewBaselineForm
from ..models import ClinicalReviewBaseline
from .modeladmin_mixins import CrfModelAdmin


@admin.register(ClinicalReviewBaseline, site=intecomm_subject_admin)
class ClinicalReviewBaselineAdmin(CrfModelAdmin):
    form = ClinicalReviewBaselineForm

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        *get_clinical_review_baseline_cond_fieldsets(),
        ("Other", {"fields": ("health_insurance", "patient_club")}),
        ("Protocol incident", {"fields": ("protocol_incident",)}),
        crf_status_fieldset_tuple,
        audit_fieldset_tuple,
    )

    radio_fields = {
        "crf_status": admin.VERTICAL,
        "health_insurance": admin.VERTICAL,
        "patient_club": admin.VERTICAL,
        "protocol_incident": admin.VERTICAL,
        **get_clinical_review_baseline_cond_radio_fields(),
    }



from django.db import models
from edc_action_item.models import ActionItem, ActionModelMixin
from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
from edc_model.models import BaseUuidModel
from edc_protocol_incident.constants import PROTOCOL_INCIDENT_ACTION
from edc_protocol_incident.model_mixins import ProtocolIncidentModelMixin
from edc_sites.model_mixins import SiteModelMixin

from ..choices import ACTION_REQUIRED


class ProtocolIncident(
    SiteModelMixin,
    ActionModelMixin,
    ProtocolIncidentModelMixin,
    NonUniqueSubjectIdentifierFieldMixin,
    BaseUuidModel,
):
    action_name = PROTOCOL_INCIDENT_ACTION

    action_item = models.ForeignKey(
        ActionItem,
        null=True,
        blank=True,
        on_delete=models.PROTECT,
        related_name="intecomm_prn_action_item",
    )

    action_required_old = models.CharField(max_length=45, choices=ACTION_REQUIRED, null=True)

    def natural_key(self):
        return (self.action_identifier,)  # noqa

    class Meta(
        ProtocolIncidentModelMixin.Meta,
        NonUniqueSubjectIdentifierFieldMixin.Meta,
        BaseUuidModel.Meta,
    ):
        indexes = (
            ProtocolIncidentModelMixin.Meta.indexes
            + NonUniqueSubjectIdentifierFieldMixin.Meta.indexes
            + BaseUuidModel.Meta.indexes
        )



from django import forms
from intecomm_form_validators.subject import ComplicationsFollowupFormValidators

from ..models import ComplicationsFollowup
from .mixins import CrfModelFormMixin


class ComplicationsFollowupForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = ComplicationsFollowupFormValidators

    class Meta:
        model = ComplicationsFollowup
        fields = "__all__"



screening_codenames = [
    "intecomm_screening.add_consentrefusal",
    "intecomm_screening.change_consentrefusal",
    "intecomm_screening.delete_consentrefusal",
    "intecomm_screening.add_subjectscreening",
    "intecomm_screening.change_subjectscreening",
    "intecomm_screening.delete_subjectscreening",
    "intecomm_screening.view_historicalsubjectscreening",
    "intecomm_screening.view_historicalconsentrefusal",
    "intecomm_screening.view_subjectscreening",
    "intecomm_screening.view_consentrefusal",
]
screening_codenames.sort()



# Generated by Django 4.1.2 on 2022-12-02 23:22

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0002_remove_historicaldminitialreview_managed_by_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="coworkers",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="Do any of your COWORKERS know about your participation in the study?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="friends",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="Do any of your FRIENDS know about your participation in the study?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="coworkers",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="Do any of your COWORKERS know about your participation in the study?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="friends",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="Do any of your FRIENDS know about your participation in the study?",
            ),
        ),
    ]



def get_search_fields(include_pii=None):
    search_fields = [
        "id",
        "screening_identifier",
        "subject_identifier",
        "hospital_identifier__exact",
        "initials__exact",
        "filing_identifier",
        "patient_log_identifier",
        "group_identifier",
        "contact_number__exact",
        "alt_contact_number__exact",
        "last_4_hospital_identifier__exact",
        "last_4_contact_number__exact",
    ]
    if include_pii:
        search_fields.extend(
            [
                "legal_name__exact",
                "familiar_name__exact",
            ]
        )
    return tuple(search_fields)



from edc_sites.site import sites


class SiteTestCaseMixin:
    default_country = "tz"

    @property
    def default_sites(self):
        return sites.get_by_country(self.default_country)

    @property
    def site_names(self):
        return [s.name for s in self.default_sites]

    @property
    def default_all_sites(self):
        return sites.all()



from __future__ import annotations

from django.utils.translation import gettext_lazy as _
from edc_model_admin.list_filters import FutureDateListFilter, PastDateListFilter


class PatientGroupApptListFilter(FutureDateListFilter):
    title = _("Appt")

    parameter_name = "appt_datetime"
    field_name = "appt_datetime"


class PatientGroupLastCallListFilter(PastDateListFilter):
    title = _("Last call")

    parameter_name = "report_datetime"
    field_name = "report_datetime"



# Generated by Django 4.2.3 on 2023-07-25 17:35
from django.core.exceptions import ObjectDoesNotExist
from django.db import migrations
from edc_list_data import PreloadData
from tqdm import tqdm

from intecomm_lists.list_data import list_data


def update_next_appointment(apps, schema_editor):
    model_cls = apps.get_model("intecomm_subject", "nextappointment")
    infosources_model_cls = apps.get_model("edc_next_appointment", "infosources")

    ld = {
        "edc_next_appointment.infosources": list_data.get("edc_next_appointment.infosources")
    }
    PreloadData(list_data=ld, apps=apps)

    total = model_cls.objects.all().count()
    for obj in tqdm(model_cls.objects.all(), total=total):
        # info_source_new
        try:
            obj.info_source_id = infosources_model_cls.objects.get(name=obj.info_source_old).id
        except ObjectDoesNotExist as e:
            names = ",".join([obj.name for obj in infosources_model_cls.objects.all()])
            raise ObjectDoesNotExist(
                f"{e}. Expected one of {names}. Got '{obj.info_source_old}'. Perhaps run "
                "post-migrate to populate list model "
                f"{infosources_model_cls._meta.label_lower}. For example, run "
                "`migrate intecomm_subject 0060` followed by `migrate`."
            )
        obj.save_base(update_fields=["info_source_id"])


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0060_historicalnextappointment_info_source_and_more"),
    ]

    operations = [migrations.RunPython(update_next_appointment)]



from django.core.validators import MaxValueValidator, MinValueValidator
from django.db import models
from edc_constants.choices import YES_NO, YES_NO_NA, YES_NO_PENDING_NA
from edc_constants.constants import HIV, NOT_APPLICABLE
from edc_crf.model_mixins import SingletonCrfModelMixin
from edc_dx_review.model_mixins import rx_initial_review_model_mixin_factory
from edc_dx_review.model_mixins.factory import dx_initial_review_model_mixin_factory
from edc_lab.choices import VL_QUANTIFIER_NA
from edc_model.models import BaseUuidModel
from edc_model.validators import date_not_future
from edc_reportable import CELLS_PER_MILLIMETER_CUBED_DISPLAY, COPIES_PER_MILLILITER

from ..choices import CARE_ACCESS
from ..model_mixins import CrfModelMixin


class HivInitialReview(
    dx_initial_review_model_mixin_factory("dx"),
    rx_initial_review_model_mixin_factory(
        "rx_init", verbose_name_label="antiretroviral therapy (ART)"
    ),
    SingletonCrfModelMixin,
    CrfModelMixin,
    BaseUuidModel,
):
    diagnosis_label = HIV

    receives_care = models.CharField(
        verbose_name="Is the patient receiving care for HIV?",
        max_length=15,
        choices=YES_NO,
    )

    clinic = models.CharField(
        verbose_name="Where does the patient receive care for HIV",
        max_length=15,
        choices=CARE_ACCESS,
        default=NOT_APPLICABLE,
    )

    clinic_other = models.CharField(
        verbose_name="If not attending here, where does the patient attend?",
        max_length=50,
        null=True,
        blank=True,
    )

    # Viral Load
    has_vl = models.CharField(
        verbose_name="Is the patient's most recent viral load result available?",
        max_length=25,
        choices=YES_NO_PENDING_NA,
        default=NOT_APPLICABLE,
    )

    vl = models.IntegerField(
        verbose_name="Most recent viral load",
        validators=[MinValueValidator(0), MaxValueValidator(9999999)],
        null=True,
        blank=True,
        help_text=COPIES_PER_MILLILITER,
    )

    vl_quantifier = models.CharField(
        max_length=10,
        choices=VL_QUANTIFIER_NA,
        null=True,
        default=NOT_APPLICABLE,
    )

    drawn_date = models.DateField(
        verbose_name="Date specimen drawn",
        validators=[date_not_future],
        null=True,
        blank=True,
        help_text="If exact date not known, please estimate",
    )

    # CD4
    has_cd4 = models.CharField(
        verbose_name="Is the patient's most recent CD4 result available?",
        max_length=25,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
    )

    cd4 = models.IntegerField(
        verbose_name="Most recent CD4",
        validators=[MinValueValidator(0), MaxValueValidator(3000)],
        null=True,
        blank=True,
        help_text=CELLS_PER_MILLIMETER_CUBED_DISPLAY,
    )

    cd4_date = models.DateField(
        verbose_name="Date of most recent CD4",
        validators=[date_not_future],
        null=True,
        blank=True,
    )

    @property
    def best_art_initiation_date(self):
        return self.rx_init_date or self.rx_init_calculated_date

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "HIV Initial Review"
        verbose_name_plural = "HIV Initial Reviews"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from intecomm_group.models import PatientGroup as BasePatientGroup


class PatientGroupRando(BasePatientGroup):
    def __str__(self):
        status = " (R)" if self.randomized else ""
        return f"{self.name.upper()}{status}"

    class Meta:
        proxy = True
        verbose_name = "Patient group randomization"
        verbose_name_plural = "Patient group randomization"



# Generated by Django 4.1.2 on 2022-11-20 21:08

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="ArvDrugs",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Arv Drugs",
                "verbose_name_plural": "Arv Drugs",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="ArvRegimens",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "ARV Regimens",
                "verbose_name_plural": "ARV Regimens",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="ClinicalWithdrawalReasons",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Clinical Withdrawal Reasons",
                "verbose_name_plural": "Clinical Withdrawal Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="ClinicServices",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Clinic Services",
                "verbose_name_plural": "Clinic Services",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="Conditions",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Conditions",
                "verbose_name_plural": "Conditions",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="DmTreatments",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Diabetes Treatments",
                "verbose_name_plural": "Diabetes Treatments",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="DrugDispensaries",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Drug Dispensaries",
                "verbose_name_plural": "Drug Dispensaries",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="DrugDispensers",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Drug Dispensers",
                "verbose_name_plural": "Drug Dispensers",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="DrugPaySources",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Drug Payment Sources",
                "verbose_name_plural": "Drug Payment Sources",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="HealthAdvisors",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Health Advisors",
                "verbose_name_plural": "Health Advisors",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="HealthFacilityTypes",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Health Facility Type",
                "verbose_name_plural": "Health Facility Types",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="HealthInterventionTypes",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Health Intervention Types",
                "verbose_name_plural": "Health Intervention Types",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="HealthServices",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Health Services",
                "verbose_name_plural": "Health Services",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="HealthTalkConditions",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Health Talk Conditions",
                "verbose_name_plural": "Health Talk Conditions",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="HealthTalkTypes",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Health Talk Type",
                "verbose_name_plural": "Health Talk Types",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="HtnTreatments",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Hypertension Treatments",
                "verbose_name_plural": "Hypertension Treatments",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="LaboratoryTests",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Laboratory Tests",
                "verbose_name_plural": "Laboratory Tests",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="LocationTypes",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Community-care location type",
                "verbose_name_plural": "Community-care location types",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="NonAdherenceReasons",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "NonAdherence Reasons",
                "verbose_name_plural": "NonAdherence Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="OffstudyReasons",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Offstudy Reasons",
                "verbose_name_plural": "Offstudy Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="ReasonsForTesting",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Reasons for Testing",
                "verbose_name_plural": "Reasons for Testing",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="RefillConditions",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Refill Conditions",
                "verbose_name_plural": "Refill Conditions",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="RxModificationReasons",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Treatment Modification Reasons",
                "verbose_name_plural": "Treatment Modification Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="RxModifications",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Treatment Modifications",
                "verbose_name_plural": "Treatment Modifications",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="SubjectVisitMissedReasons",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Subject Missed Visit Reasons",
                "verbose_name_plural": "Subject Missed Visit Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="ToxicityWithdrawalReasons",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Toxicity Withdrawal Reasons",
                "verbose_name_plural": "Toxicity Withdrawal Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="TransferReasons",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Transfer Reasons",
                "verbose_name_plural": "Transfer Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="TransportChoices",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Transport Choices",
                "verbose_name_plural": "Transport Choices",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="VisitReasons",
            fields=[
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "plural_name",
                    models.CharField(max_length=250, null=True, verbose_name="Plural name"),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
                ("id", models.AutoField(primary_key=True, serialize=False)),
            ],
            options={
                "verbose_name": "Visit Reasons",
                "verbose_name_plural": "Visit Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.AddIndex(
            model_name="visitreasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_1dbf9b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="transportchoices",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_8a0a27_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="transferreasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_58872e_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="toxicitywithdrawalreasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_710a9d_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectvisitmissedreasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_6fb3a6_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="rxmodifications",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_4fd810_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="rxmodificationreasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_c4f7bb_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="refillconditions",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_17855a_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="reasonsfortesting",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_9d7377_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offstudyreasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_c1b6d2_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="nonadherencereasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_31cb50_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="locationtypes",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_8c336e_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="laboratorytests",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_b0664c_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="htntreatments",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_ce0438_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthtalktypes",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_5f9413_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthtalkconditions",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_21baf0_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthservices",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_1604f4_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthinterventiontypes",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_9b4020_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthfacilitytypes",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_727813_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthadvisors",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_ffdb67_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="drugpaysources",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_27e420_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="drugdispensers",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_cc5dec_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="drugdispensaries",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_ffb6be_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="dmtreatments",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_aa0a3b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="conditions",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_a3d457_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="clinicservices",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_97c7c2_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="clinicalwithdrawalreasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_33f6f1_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="arvregimens",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_963095_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="arvdrugs",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="intecomm_li_id_82a046_idx",
            ),
        ),
    ]



import re

import inflect
from django.contrib import admin
from django.http import HttpResponseRedirect
from django.urls import reverse
from django.utils.html import format_html
from django_audit_fields.admin import audit_fieldset_tuple
from edc_constants.constants import UUID_PATTERN
from edc_sites.admin import SiteModelAdminMixin

from intecomm_group.exceptions import PatientGroupNotRandomized
from intecomm_group.utils import get_assignment_description_for_patient_group

from ..admin_site import intecomm_screening_admin
from ..forms.patient_group_rando_form import PatientGroupRandoForm
from ..models import PatientGroupRando
from .modeladmin_mixins import BaseModelAdminMixin

p = inflect.engine()


@admin.register(PatientGroupRando, site=intecomm_screening_admin)
class PatientGroupRandoAdmin(SiteModelAdminMixin, BaseModelAdminMixin):
    form = PatientGroupRandoForm

    show_object_tools = True
    change_list_template: str = "intecomm_screening/admin/patientgroup_change_list.html"
    change_list_help = "Searches on encrypted data work on exact uppercase matches only"
    change_list_title = PatientGroupRando._meta.verbose_name_plural
    ordering = ("site__id", "randomized_datetime")

    fieldsets = (
        (None, {"fields": ["name"]}),
        (
            "Randomize",
            {
                "description": format_html(
                    "Complete this section when the group is COMPLETE and READY to "
                    "RANDOMIZE. <BR>"
                    "<B>Important: THIS STEP CANNOT BE UNDONE</B>"
                ),
                "fields": ("randomize_now", "confirm_randomize_now"),
            },
        ),
        (
            "Randomization",
            {
                "fields": ("group_identifier", "randomized", "randomized_datetime"),
            },
        ),
        audit_fieldset_tuple,
    )

    list_display = (
        "group_name",
        "arm",
        "group_id",
        "randomized_date",
        "user_created",
        "created",
    )

    list_filter = (
        "randomized",
        "report_datetime",
    )

    search_fields = (
        "name",
        "group_identifier",
    )

    radio_fields = {
        "randomize_now": admin.VERTICAL,
    }

    readonly_fields = ("group_identifier", "randomized_datetime", "randomized")

    @admin.display(description="Patient Group", ordering="name")
    def group_name(self, obj=None):
        return str(obj)

    @admin.display(description="Randomized", ordering="randomized_datetime")
    def randomized_date(self, obj=None):
        try:
            return obj.randomized_datetime.date()
        except AttributeError:
            return None

    @admin.display(description="Group identifier", ordering="group_identifier")
    def group_id(self, obj):
        return (
            None if re.match(UUID_PATTERN, str(obj.group_identifier)) else obj.group_identifier
        )

    @admin.display(description="Randomization")
    def arm(self, obj=None):
        try:
            arm_as_str = get_assignment_description_for_patient_group(obj.group_identifier)
        except PatientGroupNotRandomized:
            url = reverse(
                "intecomm_screening_admin:intecomm_screening_patientgroup_changelist"
            )
            url = f"{url}?q={obj.name}"
            link = format_html(
                f'<a title="Go to patient group" href="{url}">Edit Patient group</a>'
            )
        else:
            url = reverse("intecomm_group_admin:intecomm_group_patientgroup_changelist")
            url = f"{url}?q={obj.name}"
            link = format_html(
                f'<a title="Go to patient groups in followup" href="{url}">{arm_as_str}</a>'
            )
        return link

    def response_post_save_change(self, request, obj):
        url = reverse("intecomm_group_admin:intecomm_group_patientgroup_changelist")
        post_url = f"{url}?q={obj.name}"
        return HttpResponseRedirect(post_url)



from __future__ import annotations

from typing import TYPE_CHECKING

from django.apps import apps as django_apps
from django.core.exceptions import ObjectDoesNotExist
from edc_constants.constants import DM, HIV, HTN, YES
from intecomm_rando.group_eligibility import assess_group_eligibility
from intecomm_rando.models import RandomizationList
from intecomm_rando.randomize_group import RandomizeGroup
from intecomm_rando.utils import update_patient_in_newly_randomized_group

from .models import PatientGroup

if TYPE_CHECKING:
    from intecomm_consent.models import SubjectConsent
    from intecomm_screening.models import PatientLog, SubjectScreening


class PatientGroupNotRandomized(Exception):
    pass


class PatientGroupUpdaterError(Exception):
    pass


class PatientGroupUpdater:
    def __init__(self, patient_group: PatientGroup, subject_identifier: str):
        self.group_name: str = patient_group.name
        self.subject_identifier = subject_identifier
        self.patient_group = patient_group
        if not patient_group.randomized:
            raise PatientGroupNotRandomized(
                f"PatientGroup has not been randomized. Got {self.group_name}."
            )
        self.patient_log: PatientLog = self.get_patient_log_or_raise(subject_identifier)
        if self.patient_group.patients.filter(id=self.patient_log.id).exists():
            raise PatientGroupUpdaterError(
                f"{self.subject_identifier} already in group {self.group_name}."
            )
        elif self.patient_log.group_identifier:
            patient_group = PatientGroup.objects.get(
                group_identifier=self.patient_log.group_identifier
            )
            raise PatientGroupUpdaterError(
                f"{self.subject_identifier} already in "
                f"group {patient_group.name} / {self.patient_log.group_identifier}."
            )
        self.subject_screening: SubjectScreening = self.get_subject_screening_or_raise(
            subject_identifier
        )
        self.subject_consent_exists_or_raise(subject_identifier)

    def add_subject_to_group(self):
        # add to patient to group
        for condition in self.conditions:
            if condition == HIV:
                self.patient_group.hiv_patients.add(self.patient_log)
            elif condition == HTN:
                self.patient_group.htn_patients.add(self.patient_log)
            elif condition == DM:
                self.patient_group.dm_patients.add(self.patient_log)
            else:
                raise PatientGroupUpdaterError(
                    f"Unknown condition. See {self.subject_identifier}. Got {condition}."
                )
            self.patient_group.patients.add(self.patient_log)
        self.patient_group.save()
        self.patient_group.refresh_from_db()
        assess_group_eligibility(self.patient_group, called_by_rando=True)
        randomize_group = RandomizeGroup(self.patient_group)
        randomize_group._update_all_for_one_patient(self.patient_log)
        rando_obj = RandomizationList.objects.get(
            group_identifier=self.patient_group.group_identifier
        )
        update_patient_in_newly_randomized_group(
            self.patient_log, rando_obj.assignment, rando_obj.allocated_datetime
        )

    @property
    def patient_log_model_cls(self) -> PatientLog:
        return django_apps.get_model("intecomm_screening.patientlog")

    @property
    def subject_screening_model_cls(self) -> SubjectScreening:
        return django_apps.get_model("intecomm_screening.subjectscreening")

    @property
    def subject_consent_model_cls(self) -> SubjectConsent:
        return django_apps.get_model("intecomm_consent.subjectconsent")

    def get_patient_log_or_raise(self, subject_identifier: str) -> PatientLog:
        """Returns the patient log or raises"""
        try:
            patient_log = self.patient_log_model_cls.objects.get(
                subject_identifier=subject_identifier
            )
        except ObjectDoesNotExist:
            raise PatientGroupUpdaterError(
                f"{self.patient_log_model_cls._meta.verbose_name} does not "
                f"exist. Got {subject_identifier}."
            )
        return patient_log

    def get_subject_screening_or_raise(self, subject_identifier: str) -> SubjectScreening:
        """Returns subject screening or raises."""
        try:
            subject_screening = self.subject_screening_model_cls.objects.get(
                subject_identifier=subject_identifier
            )
        except ObjectDoesNotExist:
            raise PatientGroupUpdaterError(
                f"{self.subject_screening_model_cls._meta.verbose_name} does not "
                f"exist. Got {subject_identifier}."
            )
        return subject_screening

    def subject_consent_exists_or_raise(self, subject_identifier) -> None:
        try:
            self.subject_consent_model_cls.objects.get(subject_identifier=subject_identifier)
        except ObjectDoesNotExist:
            raise PatientGroupUpdaterError(
                f"{self.subject_consent_model_cls._meta.verbose_name} does not "
                f"exist. Got {subject_identifier}."
            )

    @property
    def conditions(self) -> list[str]:
        conditions_screen = []
        if self.subject_screening.dm_dx == YES:
            conditions_screen.append(DM)
        if self.subject_screening.hiv_dx == YES:
            conditions_screen.append(HIV)
        if self.subject_screening.htn_dx == YES:
            conditions_screen.append(HTN)
        conditions_screen.sort()
        condition_log = [
            obj.name for obj in self.patient_log.conditions.all().order_by("name")
        ]
        if not condition_log or not conditions_screen:
            raise PatientGroupUpdaterError(
                f"No chronic conditions reported. See {self.patient_log.subject_identifier}. "
            )
        elif condition_log != conditions_screen:
            raise PatientGroupUpdaterError(
                f"Inconsistent chronic conditions reported. See "
                f"{self.patient_log.subject_identifier}. "
                f"Got {conditions_screen} != {condition_log}."
            )
        return conditions_screen



from edc_model.models import BaseUuidModel
from edc_sites.model_mixins import SiteModelMixin
from edc_visit_schedule.model_mixins import OnScheduleModelMixin


class OnScheduleComm(SiteModelMixin, OnScheduleModelMixin, BaseUuidModel):

    """A model used by the system. Auto-completed by subject_consent."""

    class Meta(OnScheduleModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "On-schedule community-based integrated care"
        verbose_name_plural = "On-schedule community-based integrated care"
        indexes = OnScheduleModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple
from edc_glucose.fieldsets import glucose_fieldset_tuple

from ..admin_site import intecomm_subject_admin
from ..forms import DmInitialReviewForm
from ..models import DmInitialReview
from .modeladmin_mixins import CrfModelAdmin


@admin.register(DmInitialReview, site=intecomm_subject_admin)
class DmInitialReviewAdmin(CrfModelAdmin):
    form = DmInitialReviewForm

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Diagnosis",
            {
                "fields": (
                    "dx_date",
                    "dx_ago",
                )
            },
        ),
        (
            "Treatment",
            {
                "fields": (
                    "managed_by",
                    "managed_by_other",
                    "rx_init_date",
                    "rx_init_ago",
                )
            },
        ),
        glucose_fieldset_tuple,
        crf_status_fieldset_tuple,
        audit_fieldset_tuple,
    )

    filter_horizontal = ["managed_by"]

    radio_fields = {
        "crf_status": admin.VERTICAL,
        "glucose_performed": admin.VERTICAL,
        "glucose_quantifier": admin.VERTICAL,
        "glucose_units": admin.VERTICAL,
        "glucose_fasting": admin.VERTICAL,
    }

    def get_form(self, request, obj=None, **kwargs):
        form = super().get_form(request, obj=obj, **kwargs)
        form = self.replace_label_text(form, "diagnosis_label", self.model.diagnosis_label)
        return form



from django.contrib import admin
from edc_facility.admin_site import edc_facility_admin
from edc_facility.modeladmin_mixins import HealthFacilityModelAdminMixin
from edc_facility.models import HealthFacility as DefaultHealthFacility
from edc_sites.admin import SiteModelAdminMixin
from edc_sites.site import sites

from intecomm_screening.admin.modeladmin_mixins import (
    BaseModelAdminMixin,
    ChangeListTopBarModelAdminMixin,
)

from .admin_site import intecomm_facility_admin
from .forms import HealthFacilityForm
from .models import HealthFacility

edc_facility_admin.unregister(DefaultHealthFacility)


@admin.register(HealthFacility, site=intecomm_facility_admin)
class HealthFacilityAdmin(
    HealthFacilityModelAdminMixin,
    SiteModelAdminMixin,
    ChangeListTopBarModelAdminMixin,
    BaseModelAdminMixin,
):
    form = HealthFacilityForm
    show_object_tools = True
    change_list_template: str = "intecomm_facility/admin/healthfacility_changelist.html"
    change_list_title = HealthFacility._meta.verbose_name_plural
    change_list_note = "These are health facilites within a hospital"

    changelist_top_bar_selected = "healthfacility"
    changelist_top_bar_add_url = "intecomm_facility_admin:intecomm_facility_healthfacility_add"

    @admin.display(description="Distance (km)", ordering="distance")
    def distance_abbrev(self, obj=None):
        return obj.distance

    def get_fieldsets(self, request, obj=None):
        fieldsets = super().get_fieldsets(request, obj=obj)
        for fieldset in fieldsets:
            if fieldset[0] == "Location":
                fields = fieldset[1]["fields"]
                fields = list(fields)
                fields.insert(0, "distance")
                fieldset[1]["fields"] = tuple(fields)
                break
        return fieldsets

    def get_list_display(self, request) -> tuple[str, ...]:
        list_display = super().get_list_display(request)
        list_display = list(list_display)
        list_display.insert(4, "distance_abbrev")
        return tuple(list_display)

    def site_name(self, obj=None):
        return sites.get(obj.site.id).name



from .community_care_location_form import CommunityCareLocationForm
from .patient_followup_call_form import PatientFollowupCallForm
from .patient_group_appointment_form import PatientGroupAppointmentForm
from .patient_group_form import PatientGroupForm
from .patient_group_meeting_form import PatientGroupMeetingForm



from django.contrib import admin
from edc_he.modeladmin_mixins import HealthEconomicsPropertyModelAdminMixin

from ...admin_site import intecomm_subject_admin
from ...forms import HealthEconomicsPropertyForm
from ...models import HealthEconomicsProperty
from ..modeladmin_mixins import CrfModelAdmin


@admin.register(HealthEconomicsProperty, site=intecomm_subject_admin)
class HealthEconomicsPropertyAdmin(HealthEconomicsPropertyModelAdminMixin, CrfModelAdmin):
    form = HealthEconomicsPropertyForm



# Generated by Django 4.2.7 on 2023-12-05 20:40

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_prn", "0014_endofstudy_intecomm_pr_action__f3bf58_idx_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["subject_identifier", "action_identifier", "site"],
                name="intecomm_pr_subject_54092b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_pr_subject_1a96f8_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_004622_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_90fc4f_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__7a579a_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=["subject_identifier", "action_identifier", "report_datetime", "site"],
                name="intecomm_pr_subject_cef1b4_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_e233b6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_7d84b5_idx"
            ),
        ),
    ]



from django import forms
from edc_crf.modelform_mixins import CrfModelFormMixin
from edc_randomization.utils import get_object_for_subject
from intecomm_form_validators.subject import LocationUpdateFormValidator

from intecomm_screening.models import PatientLog

from ..models import LocationUpdate


class LocationUpdateForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = LocationUpdateFormValidator

    @property
    def group_identifier(self) -> str:
        obj = PatientLog.objects.get(subject_identifier=self.get_subject_identifier())
        return obj.group_identifier

    def clean(self) -> dict:
        cleaned_data = super().clean()

        rando_obj = get_object_for_subject(
            self.group_identifier, "default", identifier_fld="group_identifier"
        )
        if cleaned_data.get("location") == rando_obj.assignment:
            pass
        return cleaned_data

    class Meta:
        model = LocationUpdate
        fields = "__all__"



# Generated by Django 4.2.7 on 2023-12-05 20:46

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0133_bloodresultsfbc_intecomm_su_subject_3bd165_idx_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="clinicalreviewbaseline",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_67b2fa_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="clinicalreviewbaseline",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_bee688_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="clinicalreviewbaseline",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_99c261_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="complicationsbaseline",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_c4ed1f_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="complicationsbaseline",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_00569e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="complicationsbaseline",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_a373c1_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="complicationsfollowup",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_253434_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="complicationsfollowup",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_1ed4b6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="complicationsfollowup",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_53ced3_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="concomitantmedication",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_458d49_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="concomitantmedication",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_af63b0_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="concomitantmedication",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_fa7947_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="dminitialreview",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_3991f4_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="dminitialreview",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_095258_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="dminitialreview",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_64007e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="dmmedicationadherence",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_4293d2_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="dmmedicationadherence",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_4c6294_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="dmmedicationadherence",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_85ee39_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="dmreview",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_1f36e4_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="dmreview",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_cc428d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="dmreview",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_85821d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugrefilldm",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_0b732d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugrefilldm",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_6d0dd5_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugrefilldm",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_bd9a3a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugrefillhiv",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_9cda3f_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugrefillhiv",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_40e598_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugrefillhiv",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_4e128e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugrefillhtn",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_d0bd13_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugrefillhtn",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_585432_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugrefillhtn",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_b0da16_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugsupplydm",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_9bc54e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugsupplydm",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_dcc1d5_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugsupplyhiv",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_8acc20_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugsupplyhiv",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_610af9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugsupplyhtn",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_8c1dd6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="drugsupplyhtn",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_07c10a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="eq5d3l",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_c196bb_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="eq5d3l",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_84ab2e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="eq5d3l",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_fa1acb_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="familyhistory",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_18752d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="familyhistory",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_f196cb_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="familyhistory",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_bc400c_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="glucose",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_430194_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="glucose",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_cb66f5_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="glucose",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_ef2a1c_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomics",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_a363c6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicsassets",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_b6e56a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicsassets",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_f5b8ac_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicsassets",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_dc9bf6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicshouseholdhead",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_812007_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicshouseholdhead",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_f79c92_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicshouseholdhead",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_2184dc_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicsincome",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_61d316_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicsincome",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_1cd934_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicsincome",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_7164a2_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicspatient",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_7b191c_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicspatient",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_d0c929_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicspatient",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_355d6b_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicsproperty",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_8f0447_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicsproperty",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_48227b_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomicsproperty",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_f50e97_idx"
            ),
        ),
    ]



from __future__ import annotations

from typing import Type

from django import forms
from edc_form_validators import FormValidatorMixin
from edc_screening.modelform_mixins import AlreadyConsentedFormMixin
from edc_sites.modelform_mixins import SiteModelFormMixin
from intecomm_form_validators import SubjectScreeningFormValidator

from ...models import PatientLogUg, SubjectScreeningUg
from .modelform_mixins import SubjectScreeningModelFormMixin


class SubjectScreeningUgForm(
    SubjectScreeningModelFormMixin,
    AlreadyConsentedFormMixin,
    SiteModelFormMixin,
    FormValidatorMixin,
    forms.ModelForm,
):
    form_validator_cls = SubjectScreeningFormValidator

    @property
    def patient_log_model_cls(self) -> Type[PatientLogUg]:
        return PatientLogUg

    class Meta:
        model = SubjectScreeningUg
        fields = "__all__"
        labels = {
            "consent_ability": "Is the patient able and willing to give informed consent.",
            "site": "Which study site is this?",
        }
        widgets = {
            "patient_log_identifier": forms.TextInput(attrs={"readonly": "readonly"}),
            "legal_name": forms.TextInput(attrs={"readonly": "readonly"}),
            "familiar_name": forms.TextInput(attrs={"readonly": "readonly"}),
            "initials": forms.TextInput(attrs={"readonly": "readonly"}),
            "age_in_years": forms.TextInput(attrs={"readonly": "readonly"}),
            "hospital_identifier": forms.TextInput(attrs={"readonly": "readonly"}),
        }
        help_texts = {
            "patient_log_identifier": "(read-only)",
            "site": "This question is asked to confirm you are logged in to the correct site.",
        }



# Generated by Django 5.0 on 2024-01-10 22:15

from django.db import migrations
from django.db.migrations import RunPython


def update_model_name(apps, schema_editor):
    model_cls = apps.get_model("intecomm_consent.subjectconsent")
    model_cls.objects.filter(site_id__lt=200).update(
        model_name="intecomm_consent.subjectconsentug"
    )
    model_cls.objects.filter(site_id__gte=200).update(
        model_name="intecomm_consent.subjectconsent"
    )


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_consent", "0019_historicalsubjectconsent_model_name_and_more"),
    ]

    operations = [RunPython(update_model_name)]



from django.contrib import admin

from ..admin_site import intecomm_subject_admin
from ..forms import DmMedicationAdherenceForm
from ..models import DmMedicationAdherence
from .modeladmin_mixins import CrfModelAdmin, MedicationAdherenceAdminMixin


@admin.register(DmMedicationAdherence, site=intecomm_subject_admin)
class DmMedicationAdherenceAdmin(MedicationAdherenceAdminMixin, CrfModelAdmin):
    form = DmMedicationAdherenceForm



# Generated by Django 4.2.6 on 2023-11-20 11:05

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0124_auto_20231115_0133"),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicsproperty",
            name="calculated_land_surface_area",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="m2 (system calculated)",
                max_digits=15,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(999999999.99),
                ],
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsproperty",
            name="calculated_land_surface_area",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="m2 (system calculated)",
                max_digits=15,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(999999999.99),
                ],
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_surface_area",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=15,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0.1),
                    django.core.validators.MaxValueValidator(999999999.9),
                ],
                verbose_name="Surface area",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsproperty",
            name="land_surface_area_units",
            field=models.CharField(
                choices=[
                    ("hectares", "hectares"),
                    ("acres", "acres"),
                    ("decimals", "decimals (1 decimal = hundredth of an acre)"),
                    ("sq_feet", "sq. feet (length * width)"),
                    ("sq_meters", "sq. meters (length * width)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                null=True,
                verbose_name="Surface area (units)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_surface_area",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                max_digits=15,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0.1),
                    django.core.validators.MaxValueValidator(999999999.9),
                ],
                verbose_name="Surface area",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsproperty",
            name="land_surface_area_units",
            field=models.CharField(
                choices=[
                    ("hectares", "hectares"),
                    ("acres", "acres"),
                    ("decimals", "decimals (1 decimal = hundredth of an acre)"),
                    ("sq_feet", "sq. feet (length * width)"),
                    ("sq_meters", "sq. meters (length * width)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                null=True,
                verbose_name="Surface area (units)",
            ),
        ),
    ]



from django.db import models
from edc_model.models import BaseUuidModel

from ...model_mixins import CrfModelMixin
from .model_factories import disclosure_model_mixin_factory, impact_model_mixin_factory


class SocialHarms(
    disclosure_model_mixin_factory("partner", "family", "friends", "coworkers"),
    impact_model_mixin_factory(
        "partner",
        "family",
        "friends",
        "coworkers",
        "healthcare",
    ),
    impact_model_mixin_factory(
        "other_service", lead_verbose_name="... with any other health service"
    ),
    impact_model_mixin_factory(
        "employment",
        "insurance",
    ),
    impact_model_mixin_factory(
        "other", lead_verbose_name="... with any other aspect of your life"
    ),
    CrfModelMixin,
    BaseUuidModel,
):
    other_service_impact_description = models.CharField(
        verbose_name="Please describe ...", max_length=50, null=True, blank=True
    )

    other_impact_description = models.CharField(
        verbose_name="Please describe ...", max_length=50, null=True, blank=True
    )

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Social Harms"
        verbose_name_plural = "Social Harms"



# Generated by Django 4.2.7 on 2023-12-05 20:47

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0134_clinicalreviewbaseline_intecomm_su_subject_67b2fa_idx_and_more",
        ),
    ]

    operations = [
        migrations.AddIndex(
            model_name="hivinitialreview",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_a055c4_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivinitialreview",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_21d652_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivinitialreview",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_5813f4_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivmedicationadherence",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_87f6eb_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivmedicationadherence",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_3533ce_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivmedicationadherence",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_a6d4ee_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivreview",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_39226a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivreview",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_33b07e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="hivreview",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_92f8f9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htninitialreview",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_411d3a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htninitialreview",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_4d9851_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htninitialreview",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_13e14c_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htnmedicationadherence",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_3317e5_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htnmedicationadherence",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_3a0fea_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htnmedicationadherence",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_50537a_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htnreview",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_d895a5_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htnreview",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_c47319_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="htnreview",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_af0253_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="icecapa",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_f8d820_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="icecapa",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_9cbbd9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="icecapa",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_3cffa8_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="locationupdate",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_e27dc5_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="locationupdate",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_8a3358_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="locationupdate",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_593cf3_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="malariatest",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_5275b6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="malariatest",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_551e45_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="malariatest",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_5a20bc_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="medications",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_8737ca_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="medications",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_d955ea_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="medications",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_514814_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="nextappointment",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_226937_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="nextappointment",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_382522_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="nextappointment",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_b2a703_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="otherbaselinedata",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_daeaa1_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="otherbaselinedata",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_09f4e6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="otherbaselinedata",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_16e1f9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="socialharms",
            index=models.Index(
                fields=["subject_visit", "site"], name="intecomm_su_subject_614268_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_su_subject_e4994e_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["subject_visit", "site", "panel"],
                name="intecomm_su_subject_c4f624_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["subject_visit", "panel"], name="intecomm_su_subject_01e2c9_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_su_modifie_7e0b1f_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_su_user_mo_595b8a_idx"
            ),
        ),
    ]
